@@ -75,7 +75,7 @@
 #' Use the optional \code{...} argument to explicitly supply \code{axisLabels}
 #' as a three-element character vector, see the examples below. A few additional
 #' plot options are also supported:
-#' \itemize{
+#' \describe{
 #'   \item{"lights"}{ a list of \code{light_ambient} and \code{light_directional} objects}
 #'   \item{"cex.lab"}{ font size scale factor for the axis labels}
 #'   \item{"cex.axis"}{ font size scale factor for the axis tick labels}
@@ -86,6 +86,7 @@
 #'   \item{"main"}{ Plot title text}
 #'   \item{"top"}{ Top location in pixels from top of the plot title text}
 #'   \item{"left"}{ Left location in pixels from center of the plot title text}
+#'   \item{"program"}{ User-supplied JavaScript run on plot initialization}
 #' }
 #' The default CSS font string is "48px Arial". Note that the format of this
 #' font string differs from, for instance, the usual `par(font.axis)`.
@@ -95,13 +96,13 @@
 #' or a vector of character values of the same length as \code{x}. All
 #' character values are used literally ('+', 'x', '*', etc.) except for the
 #' following special cases:
-#' \itemize{
+#' \describe{
 #'   \item{"o"}{ Plotted points appear as 3-d spheres.}
 #'   \item{"@"}{ Plotted points appear as stroked disks.}
 #'   \item{"."}{ Points appear as tiny squares.}
 #' }
 #' Character strings of more than one character are supported--see the examples.
-#' The \code{@} and {.} option exhibit the best performance, consider using
+#' The "\code{@}" and "\code{.}" options exhibit the best performance, consider using
 #' one of those to plot large numbers of points.
 #'
 #' Set the optional experimental \code{use.orbitcontrols=TRUE} argument to
@@ -111,7 +112,7 @@
 #' See \code{\link{lines3d}} for an alternative interface.
 #' Lines are optionally drawn between points specified in \code{x, y, z} using
 #' the following new plot options.
-#' \itemize{
+#' \describe{
 #'   \item{"from"}{ A numeric vector of indices of line starting vertices corresponding to entries in \code{x}.}
 #'   \item{"to"}{ A numeric vector exactly as long as \code{from} of indices of line ending vertices corresponding
 #'       to entries in \code{x}.}
@@ -141,7 +142,8 @@
 #' in \code{x, y, z}.
 #'
 #' @references
-#' The three.js project: \url{http://threejs.org}. The HTML Widgets project: \url{http://htmlwidgets.org}.
+#' The three.js project: \url{https://threejs.org}. The HTML Widgets project:
+#" \url{https://www.htmlwidgets.org}.
 #'
 #' @examples
 #' # Example 1 from the scatterplot3d package (cf.)
@@ -369,7 +371,7 @@ scatterplot3js <- function(
       i <- (abs(x) < 0.01 & x != 0)
       if (any(i))
       {
-        ans[i] <- sprintf("%.2e", x)
+        ans[i] <- sprintf("%.2e", x[i])
       }
       ans
     }
